#
# spec file for package udiskie
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           udiskie
Version:        2.5.3
Release:        2.1
Summary:        Removable disk automounter for udisks
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/coldfix/udiskie
Source:         https://files.pythonhosted.org/packages/source/u/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  asciidoc
BuildRequires:  fdupes
# Needed for typelib() - Requires.
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxslt-tools
BuildRequires:  python-rpm-macros
# Runtime dependencies:
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
BuildRequires:  typelib(Gtk) = 3.0
BuildRequires:  typelib(Notify)
Requires:       gdk-pixbuf-loader-rsvg
Requires:       python3-PyYAML
Requires:       python3-docopt
Requires:       python3-gobject
Requires:       python3-setuptools
Requires:       python3-xml
Requires:       udisks2
Requires:       typelib(Gtk) = 3.0
Recommends:     %{name}-lang
# this package does not exist on Tumbleweed and conflicts with python311-keyring-keyutils whose module is also named 'keyutils'
Recommends:     python3-keyutils
BuildArch:      noarch

%description
udiskie is a UDisks front-end that allows to manage removeable media such as CDs
or flash drives from userspace. Its features include:

- automount removable media when inserted
- notifications (on insertion, mount, unmount, …)
- GTK tray icon to manage all available devices
- command line tools for manual un-/mounting
- support for LUKS encrypted devices
- password caching
- works with either udisks1 or udisks2
- an extensible code base (python)
- a maintainer who is open for suggestions;)

%lang_package

%prep
%autosetup
# work-around Python error in easy_install.py (setuptools)
sed -e '/ScriptWriter.template/s/^/#/g' -i setup.py

%build
%python3_build

%install
%python3_install

make %{?_smp_mflags} -C doc
install -Dm 0644 doc/%{name}.8 %{buildroot}%{_mandir}/man8/%{name}.8
# Create man pages for other binaries
for other in %{name}-mount %{name}-umount %{name}-info; do
  echo ".so man8/%{name}.8" > %{buildroot}%{_mandir}/man8/"${other}.8"
done

%fdupes %{buildroot}%{python3_sitelib}/%{name}/
%fdupes %{buildroot}%{_mandir}/man8/

%find_lang %{name}

%files
%doc CHANGES.rst README.rst
%license COPYING
%{_bindir}/%{name}*
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-*-py%{py3_ver}.egg-info
%{_mandir}/man?/%{name}*.?%{ext_man}
%{_datadir}/zsh/site-functions/_udiskie*
%{_datadir}/bash-completion/completions/*

%files lang -f %{name}.lang

%changelog
* Tue Dec 10 2024 Michael Pujos <pujos.michael@gmail.com>
- fix install error
* Thu Apr 25 2024 Michael Pujos <pujos.michael@gmail.com>
- removed fix-keyutils-module-conflict.patch, fixed upstream
- Update to 2.5.3:
  * allow matching against a list of values in config rules (device_config)
  * fix --terminal command line option (was not doing anything)
  * fix AttributeError when python-keyring-keyutils is installed instead of
    keyutils
* Mon Mar 11 2024 Michael Pujos <pujos.michael@gmail.com>
- added fix-keyutils-module-conflict.patch to fix failure for udiskie
  to start due to conflict with package python311-keyring-keyutils
  providing module 'keyutils' while udiskie expects a module with that
  name from (optionally installed) package 'python3-keyutils'
  (which does not exist in the repo)
- Update to 2.5.2:
  * drop external dependency on distutils
  * rename --notify-command to --event-hook to prevent misunderstandings
- Update to 2.5.1:
  * fix default install location for bash completion scripts
  * fix zsh completion for device names with spaces
- Update to 2.5.0:
  * add bash completions for CLI options (thanks @oersen)
  * updates for translations
  * added German translation
  * add bright outlines for wayland icons in dark themes
  * ignore snap loop devices by default
  * maintenance on CI workflows
  * fix KeyError when properties are invalidated multiple times
* Wed Mar  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.2:
  * add support for AyatanaAppIndicator3
  * setup loop devices in read-write mode if sufficient permissions are available
  * add icon name that is specifically designed for tray panel
  * try to detect installed translation files also in non-system installations
  * make it possible to override localedir manually using the TEXTDOMAINDIR environment variable
  * fix: buttons in "device-added" notifications always mounting the last partition instead of the selected one
  * fix incorrect use of wayland settings (appindicator+workarounds) within X session,
    if a wayland session is or was active under the same user (even if that was in a different login session)
  * fix incorrect display of image menu items under X due to caching
  * don't swallow STDOUT for notify-commands
  * default to appindicator if tray is requested under wayland
  * don't auto-disable tray when running in "pure" wayland session
  * set window role on the password dialog
  * remove unneeded xdg from optional dependencies
  * fix a typo in Spanish translation and update russian translation files
* Tue May  5 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.1.1
  * handle XDG_CONFIG_HOME variable without external pyxdg dependency
  * silence warning when using AppIndicator
  * make ``--appindicator`` sufficient to show icon (previously additionally
    required ``--tray``)
  * improve wording in password dialog "Remember" -> "Cache"
  * make some of the logging more concise
  * fix recursive adding/removing of some child devices:
  - fix incorrect root device detection for devices without Drive property
    (e.g. children of loop devices)
  - fix ``--detach`` option when applied to partitions of loop devices
* Tue Feb  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.1.0
  * fix some typos (thanks @torstehu, #197)
  * change how device rules are evaluated: lookup undecided rules on parent device (fixes issue with filters not applying to subdevices of a matched device, see #198)
  * change builtin rules to not show loop devices with HintIgnore, see #181
  * change how is_external attribute is compute: use the value from udisks directly (fixes issue with is_external property not behaving as expected, see #185)
  * add 'skip' keyword for rules to skip evaluation of further rules on this device, and continue directly on the parent
  * fix user commands that output non-utf8 data
  * fix exception when using non-device parameters with DeviceCommand (e.g. in --notify-command)
  * hotfix for automounting being broken since 2.0.0
  * use importlib.resources directly on py3.7 and above, rather than requiring importlib_resources as additional dependency
  * require python >= 3.5
  * drop python2 support
  * drop udisks1 support
  * drop command line options corresponding to udisks version selection (-1, -2)
  * use py35's async def functions -- improving stack traces upon exception
  * internal refactoring and simplifications
  * add "show password" checkbox in password dialog
  * keep password dialog always on top
  * fix stdin-based password prompts
  * add russian translations (thanks @mr-GreyWolf)
  * fixed deprecation warnings in setup.py (thanks @sealj553)
* Thu Jan 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use python macros for build and install to keep working under
  python 3.7
* Wed May 23 2018 sebix+novell.com@sebix.at
- initial package for udiskie-1.7.5
